@@ -149,7 +149,6 @@ class prefacturacionController extends Controller
     }
     public function vistaPreviaServicio(Request $request)
     {
-
         $fechaWhere = $request->fecha;
 
         $uf = $this->calcularUF();
@@ -168,6 +167,8 @@ class prefacturacionController extends Controller
             asignacion_solicitudes.fecha_local as fecha_instalacion,
             api_solicitudes.sCliente,
             api_solicitudes.sSC,
+                        api_solicitudes.Smarca,
+            api_solicitudes.sModelo,
             api_solicitudes.sRegion,
             api_solicitudes.sComuna,
             api_solicitudes.sSerie,
@@ -207,11 +208,29 @@ class prefacturacionController extends Controller
             ->get();
 
         $kilometros = 0;
+        // $valor_kilometro  = 1;
 
+        $valor_kilometro = DB::table('proyectos')
+        ->select('proyectos.valor_kilometro', 'proyectos.costo_usuarioadicional')
+        ->where('proyectos.nombre', "=", "SERVICIOS")
+        ->get();
+    $valor_usuarioadicional = DB::table('proyectos')
+        ->select('proyectos.costo_usuarioadicional')
+        ->where('proyectos.nombre', "=","SERVICIOS")
+        ->get();
+
+        $valor_kilometro = $valor_kilometro[0]->valor_kilometro;
+        $valor_usuarioadicional = $valor_usuarioadicional[0]->costo_usuarioadicional;
+
+
+        
         return view('solicitudes_servicios.ver_vistapreviaservicio', compact(
             'servicios',
             'carga_select',
             'uf',
+            'valor_kilometro',
+            'valor_usuarioadicional',
+            // 'valor_kilometro'
         ));
     }
     public function filtrarFecha(Request $request, $banco = '')
@@ -335,6 +354,8 @@ class prefacturacionController extends Controller
         checklist_instalacions.Cstipo_sucursal,
         checklist_instalacions.Csdireccion,
         checklist_instalacions.estado_inicio,
+          checklist_instalacions.CsModelo,
+        checklist_instalacions.Csmarca,
         checklist_instalacions.Csserie_es,
         asignacion_instalacions.estado_asignacion,
         instalacions.id,
