@@ -33,12 +33,20 @@ class SetBd
       return $next($request);
     } else {
 
-      // return redirect()
-      // ->back()
-      // ->with('mensaje_error','ERROR, RUT NO IDENTIFICADO');
-      Session::flash('mensaje_error', 'ERROR, RUT NO IDENTIFICADO');
-      return redirect()->to('/api/identificacion?error=' . "1");
-      // return redirect('/api/identificacion');
+      // // return redirect()
+      // // ->back()
+      // // ->with('mensaje_error','ERROR, RUT NO IDENTIFICADO');
+      // Session::flash('mensaje_error', 'ERROR, RUT NO IDENTIFICADO');
+      // return redirect()->to('/api/identificacion?error=' . "1");
+      // // return redirect('/api/identificacion');
+      $nombreDB = strtoupper($request->proveedor);
+      session(['nameBd89' => $nombreDB]);
+
+      DB::purge('mysql');
+      Config::set('database.connections.mysql.database', $nombreDB);
+      DB::reconnect('mysql'); //Asigno la nueva conexión al sistema. 
+
+      return $next($request);
     }
   }
 }
