@@ -420,7 +420,7 @@ $nombre_DB = DB::connection()->getDatabaseName();
 </div>
 <!--Modal Historial instalacion-->
 <div class="modal" id="modalver_historial_check">
-  <div class="modal-dialog modal-xl">
+  <div class="modal-dialog modal-xl modal-3xl modal-dialog-scrollable">
     <div class="modal-content">
       <!-- Modal Header -->
       <div class="modal-header">
@@ -434,6 +434,8 @@ $nombre_DB = DB::connection()->getDatabaseName();
               <th scope="col">N° Visita</th>
               <th scope="col">Tecnico</th>
               <th scope="col">N° de serie</th>
+              <th scope="col">Marca </th>
+
               <th scope="col">Modelo </th>
               <th scope="col">Direccion</th>
               <th scope="col">Region</th>
@@ -651,4 +653,11 @@ $nombre_DB = DB::connection()->getDatabaseName();
     });
   });
 </script>
-@endsection
\ No newline at end of file
+@endsection
+
+<style>
+.modal-3xl{
+        max-width: 1900 !important;
+  
+}
+</style>
\ No newline at end of file
