@@ -107,6 +107,8 @@
 				<th class="th-head border-th separador-v" colspan="1">Fecha (Visita)</th>
 				<th class="th-head border-th separador-v" colspan="1">Comuna</th>
 				<th class="th-head border-th separador-v" colspan="1">Dirección y Cliente</th>
+				<th class="th-head border-th separador-v" colspan="1">Id Sala</th>
+
 				<th class="th-head border-th separador-v" colspan="1">Estado</th>
 				<th class="th-head border-th separador-v" colspan="1">Serie</th>
 				<th class="th-head border-th separador-v" colspan="1">Asignación</th>
@@ -118,12 +120,16 @@
 		<!-- RESULTADOS -->
 		<tbody>
 			<!-- RESULTADOS -->
-			@if(!empty($datos_asignacion3))
+						{{-- para no mostrar 1 == 2 --}}
+
+			@if(!empty($datos_asignacion3)  && 1==2) )
 			@foreach ($datos_asignacion3 as $los_datos)
 			<tr>
 				<td>{{Carbon\Carbon::createFromDate($los_datos->fecha_visita)->format('d-m-Y')}}</td>
 				<td>{{$los_datos->csComuna ?? ''}}</td>
 				<td>{{$los_datos->Csdireccion}} ({{$los_datos->Cscliente}} )</td>
+				<td>{{$los_datos->idSala}} </td>
+
 				@if($los_datos->estado_asignacion == "tarea_asignada")
 				<td class="pendiente" style="text-transform: ">Tarea Asignada</td>
 				@elseif($los_datos->estado_asignacion == "pendiente")
@@ -191,12 +197,16 @@
 			</tr>
 			@endforeach
 			@endif
-			@if(!empty($datos_asignacion2))
+						{{-- para no mostrar 1 == 2 --}}
+
+			@if(!empty($datos_asignacion2)  && 1==2))
 			@foreach ($datos_asignacion2 as $los_datos)
 			<tr>
 				<td>{{Carbon\Carbon::createFromDate($los_datos->fecha_visita)->format('d-m-Y')}}</td>
 				<td>{{$los_datos->csComuna ?? ''}}</td>
 				<td>{{$los_datos->Csdireccion}} ({{$los_datos->Cscliente}} )</td>
+				<td>{{$los_datos->idSala}} </td>
+
 				@if($los_datos->estado_asignacion == "tarea_asignada")
 				<td class="pendiente" style="text-transform: ">Tarea Asignada</td>
 				@elseif($los_datos->estado_asignacion == "pendiente")
@@ -264,11 +274,15 @@
 			@endforeach
 			@endif
 			@if(!empty($datos_asignacion))
-			@foreach ($datos_asignacion as $los_datos)
+			@for ($i = 0; $i < count($datos_asignacion); $i++) 
+
+			@foreach ($datos_asignacion[$i] as $los_datos)
 			<tr>
 				<td>{{Carbon\Carbon::createFromDate($los_datos->fecha_visita)->format('d-m-Y')}}</td>
 				<td>{{$los_datos->csComuna ?? ''}}</td>
 				<td>{{$los_datos->Csdireccion}} ({{$los_datos->Cscliente}} )</td>
+				<td>{{$los_datos->idSala}} </td>
+
 				@if($los_datos->estado_asignacion == "tarea_asignada")
 				<td class="pendiente" style="text-transform: ">Tarea Asignada</td>
 				@elseif($los_datos->estado_asignacion == "pendiente")
@@ -334,6 +348,8 @@
 				</td>
 			</tr>
 			@endforeach
+			@endfor
+
 			@endif
 		</tbody>
 		<!-- FIN RESULTADOS -->
