@@ -136,6 +136,9 @@
                 <th class="th-head border-th separador-v" colspan="1">Fecha Instalación</th>
                 <th class="th-head border-th separador-v" colspan="1">Check Finalizado</th>
                 <th class="th-head border-th separador-v" colspan="1">N° de serie</th>
+                <th class="th-head border-th separador-v" colspan="1">Marca</th>
+                <th class="th-head border-th separador-v" colspan="1">Modelo</th>
+
                 <th class="th-head border-th separador-v" colspan="1">Sucursal</th>
                 <th class="th-head border-th separador-v" colspan="1">Direccion</th>
                 <th class="th-head border-th separador-v" colspan="1">Regi&oacute;n</th>
@@ -195,6 +198,11 @@
                 <td class="w-sm-input-table">Garantia</td>
                 @elseif($los_dato->tipos_visitas_id == 6)
                 <td class="w-sm-input-table">Mantencion</td>
+                @elseif($los_dato->tipos_visitas_id == 7)
+                <td class="w-sm-input-table">Embalaje</td>
+                @else 
+                <td class="w-sm-input-table">Verificar con Soporte</td>
+
                 @endif
                 {{-- FECHA INICIO--}}
                 <td class="w-sm-input-table">{{Carbon\Carbon::createFromDate($los_dato->fecha_inicio)->format('d-m-Y')}}</td>
@@ -210,6 +218,9 @@
                 @else
                 <td class="w-sm-input-table">{{$los_dato->CsSerie ??  ''}}</td>
                 @endif
+
+                <td class="w-sm-input-table">{{$los_dato->Csmarca ??  ''}}</td>
+                <td class="w-sm-input-table">{{$los_dato->CsModelo ??  ''}}</td>
                 {{-- SUCURSAL --}}
                 <td class="w-sm-input-table">{{$los_dato->Cstipo_sucursal ?? 'DESCONOCIDO'}}</td>
                 {{-- DIRECCION --}}
@@ -225,7 +236,7 @@
                         @if ($regio->des_region == $los_dato->sRegion || $regio->num_r == $los_dato->sRegion || $regio->abreviatura == $los_dato->sRegion || $regio->num_region == $los_dato->sRegion)
                         <option selected value="{{ $regio->des_region}}" id="region_modificable" name="region_modificable">{{ ucfirst(strtolower($regio->des_region)) }}</option>
                         @else
-                        <option value="{{ $regio->id_regiones}}" id="region"> {{ ucfirst(strtolower($regio->des_region)) }}</option>
+                        <option value="{{ $regio->des_region}}" id="region"> {{ ucfirst(strtolower($regio->des_region)) }}</option>
                         @endif
                         @endforeach
                     </select>
@@ -1102,9 +1113,9 @@
         ciudadBase = "";
         $('#tabla tr').each(function(index, element) {
             if (index != 0) {
-                region = $(element).find("td").eq(10).html();
+                region = $(element).find("td").eq(12).html();
                 regionModificable = $(".regionModificable_" + index).val();
-                ciudad = $(element).find("td").eq(12).html();
+                ciudad = $(element).find("td").eq(14).html();
                 ciudadBase = $(".ciudadModificable_" + index).val();
                 valorKilometros = $("#valorKilometros").val();
                 valorUf = $("#valorUf").val();
@@ -1151,16 +1162,16 @@
                                 $("#mensajeAlerta").css("display", "none");
                             }
                             if (data == "No Existe Ciudad" || data == "No Existe Kilometros Asociados") {
-                                $(element).find("td").eq(19).html(data);
+                                $(element).find("td").eq(21).html(data);
                             } else {
-                                $(element).find("td").eq(19).html(commaSeparateNumber(data));
+                                $(element).find("td").eq(21).html(commaSeparateNumber(data));
                             }
                             //sub total = uf * valor atencion
                             // valorAtencion = $(element).find("td").eq(16).html();
                             valorAtencion = $(".valorAtencion_" + index).val();
                             subTotal = valorAtencion * parseFloat(valorUf);
                             console.log(subTotal);
-                            $(element).find("td").eq(18).html(commaSeparateNumber(subTotal));
+                            $(element).find("td").eq(20).html(commaSeparateNumber(subTotal));
                             //valor traslado = (kilometros * 2) * valor kilometro
                             data = data.replace(",", ".");
                             valorTraslado_a = parseFloat(data) * 2;
@@ -1200,7 +1211,7 @@
                             costoFinal = parseFloat(valorTraslado2) + parseFloat(subTotal) + parseFloat(costoUsuarioAdicionalPesos);
                             costoFinal = commaSeparateNumber(costoFinal);
                             //$(element).find("td").eq(22).html(costoFinal+"x"+valorTraslado2+"x"+subTotal+"x"+costoUsuarioAdicionalPesos);
-                            $(element).find("td").eq(22).html(costoFinal);
+                            $(element).find("td").eq(24).html(costoFinal);
                             valorTraslado = valorTraslado.replace(",", "");
                             tol = parseInt(valorTraslado) + parseInt(tol);
                             console.log(subTotal);
@@ -1333,9 +1344,13 @@
             cuerpoA += "<td>" + "<h3>" + "Check Instalaci&oacute;n" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "Fecha Finalizado" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "N&deg; de serie" + "</h3>" + "</td>";
+            cuerpoA += "<td>" + "<h3>" + "Marca" + "</h3>" + "</td>";
+            cuerpoA += "<td>" + "<h3>" + "Modelo" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "Sucursal" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "Direccion" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "Regi&oacute;n" + "</h3>" + "</td>";
+           
+
             cuerpoA += "<td>" + "<h3>" + "Regi&oacute;n Seleccionada" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "Ciudad" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "Ciudad Seleccionada" + "</h3>" + "</td>";
@@ -1375,9 +1390,13 @@
                     acumulable += "<td>" + $(element).find("td").eq(8).html() + "</td>";
                     acumulable += "<td>" + $(element).find("td").eq(9).html() + "</td>";
                     acumulable += "<td>" + $(element).find("td").eq(10).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(11).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(12).html() + "</td>";
+
                     //region seleccionada
                     acumulable += "<td>" + $(".regionModificable_" + index).val() + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(12).html() + "</td>";
+                    
+                    acumulable += "<td>" + $(element).find("td").eq(14).html() + "</td>";
                     //ciudad Seleccionada
                     if (seleccionado == 0) {
                         acumulable += "<td>" + "No Seleccionado" + "</td>";
@@ -1427,16 +1446,19 @@
                     if (seleccionado == 15) {
                         acumulable += "<td>" + "Arica" + "</td>";
                     }
-                    acumulable += "<td>" + $(element).find("td").eq(14).html() + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(15).html() + "</td>";
+                    if (seleccionado == 16) {
+                        acumulable += "<td>" + "Ñuble" + "</td>";
+                    }
                     acumulable += "<td>" + $(element).find("td").eq(16).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(17).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(18).html() + "</td>";
                     acumulable += "<td>" + $(".valorTasladoModificale" + index).val().replaceAll(",", ".") + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(18).html().replaceAll(",", ".") + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(19).html() + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(20).html() + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(21).html().replaceAll(",", ".") + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(20).html().replaceAll(",", ".") + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(21).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(22).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(23).html().replaceAll(",", ".") + "</td>";
                     acumulable += "<td>" + z + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(22).html().replaceAll(",", ".") + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(24).html().replaceAll(",", ".") + "</td>";
                     acumulable += "</tr>";
                 }
             });
@@ -1487,9 +1509,9 @@
     $(document).ready(function() {
         $("#exportarExcel").click(function() {
             $('#tabla tr').each(function(index, element) {
-                traslado = $(element).find("td").eq(9).html();
-                subtotal = $(element).find("td").eq(10).html();
-                km = $(element).find("td").eq(12).html();
+                traslado = $(element).find("td").eq(11).html();
+                subtotal = $(element).find("td").eq(12).html();
+                km = $(element).find("td").eq(14).html();
                 variable = $("#variable").val();
                 variable1 = $("#variable1").val();
                 variable2 = $("#variable2").val();
