@@ -162,18 +162,16 @@
          <td class="title-table" style="border-right: solid 2px #fff">
                <h4>Equipo</h4>
             </td>
+            <td class="title-table" style="border-right: solid 2px #fff">
+               <h4>Marca</h4>
+            </td>
             <td class="title-table" style="border-right: solid 2px #fff">
                <h4>Modelo</h4>
             </td>
             <td class="title-table" style="border-right: solid 2px #fff">
                <h4>Serie</h4>
             </td>
-            <td class="title-table" style="border-right: solid 2px #fff">
-               <h4>Cont. B/N</h4>
-            </td>
-            <td class="title-table" style="border-right: solid 2px #fff">
-               <h4>Cont. Color</h4>
-            </td>
+         
          </tr>
          <tr>
          <td>
@@ -181,6 +179,11 @@
                   <span>{{$asignacion_solicitudes[0]->equipos ?? ''}}</span>
                </p>
             </td>
+            <td>
+               <p style="text-transform:uppercase;text-align:center;">
+                  <span>{{$asignacion_solicitudes[0]->Smarca ?? ''}}</span>
+               </p>
+            </td>
             <td>
                <p style="text-transform:uppercase;text-align:center;">
                   <span>{{$asignacion_solicitudes[0]->sModelo ?? ''}}</span>
@@ -191,6 +194,28 @@
                   <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->sSerie ?? ''}}</p>
                </span>
             </td>
+
+         </tr>
+      </tbody>
+   </table>
+   <!--USB E IP-->
+   <table width="100%" border="0" cellspacing="0" cellpadding="0">
+      <tbody>
+         <tr align="center">
+            <td class="title-table" style="border-right: solid 2px #fff">
+               <h4>Cont. B/N</h4>
+            </td>
+            <td class="title-table" style="border-right: solid 2px #fff">
+               <h4>Cont. Color</h4>
+            </td>
+            <td class="title-table" style="border-right: solid 2px #fff">
+               <h4>IP</h4>
+            </td>
+            <td class="title-table" style="border-right: solid 2px #fff">
+               <h4>USB</h4>
+            </td>
+         </tr>
+         <tr>
             <td>
                <span>
                   <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->contador_bn ?? ''}}</p>
@@ -201,21 +226,6 @@
                   <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->contador_color ?? ''}}</p>
                </span>
             </td>
-         </tr>
-      </tbody>
-   </table>
-   <!--USB E IP-->
-   <table width="100%" border="0" cellspacing="0" cellpadding="0">
-      <tbody>
-         <tr align="center">
-            <td class="title-table" style="border-right: solid 2px #fff">
-               <h4>IP</h4>
-            </td>
-            <td class="title-table" style="border-right: solid 2px #fff">
-               <h4>USB</h4>
-            </td>
-         </tr>
-         <tr>
             <td>
                <span>
                   <p style="text-transform:uppercase;text-align:center;">{{$asignacion_solicitudes[0]->ip ?? ''}}</p>
@@ -325,6 +335,8 @@
    <h3><strong>Cambios de piezas y partes sujeto a cobro</strong></h3>
    <!--SOLICITUD ACCESORIOS-->
    <hr style="margin: 10px 0">
+      <h3><strong>Motivo: </strong> {{$asignacion_solicitudes[0]->motivo_accesorio}}</h3>
+
    <h3><strong>Partes Dañanadas</strong></h3>
    <table width="100%" border="0" cellspacing="0" cellpadding="0">
       <tbody>
@@ -448,6 +460,68 @@
 
    <hr style="margin: 10px 0">
 
+   <h3><strong>Instalacion de accesorios</strong></h3>
+   <table width="100%" border="0" cellspacing="0" cellpadding="0">
+      <tbody>
+         <tr align="center">
+            <td class="title-table" style="border-right: solid 2px #fff">
+               <h4>Nombre de la pieza</h4>
+            </td>
+            <td class="title-table" style="border-right: solid 2px #fff">
+               <h4>Numero de parte</h4>
+            </td>
+            <td class="title-table" style="border-right: solid 2px #fff">
+               <h4>S/N parte</h4>
+            </td>
+            <td class="title-table" style="border-right: solid 2px #fff">
+               <h4>Cantidad</h4>
+            </td>
+            {{-- <td class="title-table" style="border-right: solid 2px #fff">
+               <h4>Observaciones</h4>
+            </td> --}}
+         </tr>
+         						@if(count($instalacion_accesorios) != 0)
+
+         @foreach ($instalacion_accesorios as $key => $los_datos)
+												<tr>
+													<td>
+														{{$los_datos->descripcion}}
+													</td>
+													<td>
+														{{$los_datos->articulo}}
+													</td>
+													<td>
+														{{$los_datos->serie_parte}}
+													</td>
+													<td>
+														{{$los_datos->cantidad}}
+													</td>
+												</tr>
+			@endforeach
+         @endif
+         {{-- @foreach ($instalacion_accesorios as $key => $los_datos)
+         <tr>
+             <td>
+               <p style="text-transform:uppercase;text-align:center;"><span>{{$los_datos->nombre_parte}}</span></p>
+            </td>
+            <td><span>
+                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->numero_parte}}
+               </span></td>
+            <td><span>
+                  <p style="text-transform:uppercase;text-align:center;"></p>{{$los_datos->serie_parte}}
+               </span></td>
+            <td><span>
+                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->cantidad}}
+               </span></td>
+            <td><span>
+                  <p style="text-transform:uppercase;text-align:center;"></p> {{$los_datos->observacion}}
+               </span></td> 
+         </tr>
+      </tbody>
+      @endforeach --}}
+   </table>
+   <hr style="margin: 10px 0">
+
    <!--<h3><strong>Nº de serie, componentes sustituidos</strong></h3>
 
    <div class="title-table" style="padding: 2px 20px; text-align:center;border-bottom: solid 2px #fff;">
