@@ -24,7 +24,7 @@
             <input type="text" class="form-control mayuscula" id="valorKilometros" name="" value="{{$valor_kilometro ?? 'Sin Información'}}" placeholder="$ 200 x KM" onkeyup="PasarValor();">
         </div>
         <div class="col-sm-4 form-group ">
-            <label>Valor de atencion</label>
+            <label>Valor usuario adicional</label>
             <input type="text" class="form-control mayuscula valorAtencion" id="valorUsuarioadicional" name="" value="{{$valor_usuarioadicional ?? 'Sin Información'}}" placeholder=" UF" onkeyup="PasarValor();">
         </div>
     </div>
@@ -96,6 +96,9 @@
                 <th class="th-head border-th separador-v" colspan="1">Check Finalizado</th>
                 <th class="th-head border-th separador-v" colspan="1">N° de serie</th>
                 <th class="th-head border-th separador-v" colspan="1">sSC</th>
+                <th class="th-head border-th separador-v" colspan="1">Marca</th>
+
+                <th class="th-head border-th separador-v" colspan="1">Modelo</th>
                 <th class="th-head border-th separador-v" colspan="1">Direccion</th>
                 <th class="th-head border-th separador-v" colspan="1">Regi&oacute;n</th>
                 <th class="th-head border-th separador-v" colspan="1" style="border-right: 0;">Regi&oacute;n Modificable</th>
@@ -155,6 +158,11 @@
                 <td class="w-sm-input-table">{{$los_dato->sSerie ??  ''}}</td>
                 {{-- sSC --}}
                 <td class="w-sm-input-table">{{$los_dato->sSC ??  ''}}</td>
+                         {{-- Smarca --}}
+               <td class="w-sm-input-table">{{$los_dato->Smarca ??  ''}}</td>
+                 {{-- sModelo --}}
+                 <td class="w-sm-input-table">{{$los_dato->sModelo ??  ''}}</td>
+               
                 {{-- SUCURSAL --}}
                 {{-- DIRECCION --}}
                 <td class="w-input-table">{{$los_dato->sDireccion ?? 'DESCONOCIDO'}}</td>
@@ -286,9 +294,9 @@
         ciudadBase = "";
         $('#tabla tr').each(function(index, element) {
             if (index != 0) {
-                region = $(element).find("td").eq(10).html();
+                region = $(element).find("td").eq(12).html();
                 regionModificable = $(".regionModificable_" + index).val();
-                ciudad = $(element).find("td").eq(12).html();
+                ciudad = $(element).find("td").eq(14).html();
                 ciudadBase = $(".ciudadModificable_" + index).val();
                 valorKilometros = $("#valorKilometros").val();
                 valorUf = $("#valorUf").val();
@@ -334,16 +342,16 @@
                                 $("#mensajeAlerta").css("display", "none");
                             }
                             if (data == "No Existe Ciudad" || data == "No Existe Kilometros Asociados") {
-                                $(element).find("td").eq(19).html(data);
+                                $(element).find("td").eq(21).html(data);
                             } else {
-                                $(element).find("td").eq(19).html(commaSeparateNumber(data));
+                                $(element).find("td").eq(21).html(commaSeparateNumber(data));
                             }
                             valorAtencion = $(".valorAtencion_" + index).val();
                             //valorAtencion = $(".valorAtencion").val();
                             subTotal = valorAtencion * parseFloat(valorUf);
                             //console.log(subTotal);
                             //console.log(subTotal);
-                            $(element).find("td").eq(18).html(commaSeparateNumber(subTotal));
+                            $(element).find("td").eq(20).html(commaSeparateNumber(subTotal));
                             data = data.replace(",", ".");
                             valorTraslado_a = parseFloat(data) * 2;
                             valorKilometros = valorKilometros.replace(",", ".");
@@ -370,7 +378,7 @@
                             costoFinal = parseFloat(valorTraslado2) + parseFloat(subTotal);
                             costoFinal = commaSeparateNumber(costoFinal);
                             //console.log(costoFinal);
-                            $(element).find("td").eq(20).html(costoFinal);
+                            $(element).find("td").eq(22).html(costoFinal);
                             valorTraslado = valorTraslado.replace(",", "");
                             tol = parseInt(valorTraslado) + parseInt(tol);
                             //console.log(subTotal);
@@ -458,6 +466,9 @@
             cuerpoA += "<td>" + "<h3>" + "Check Finalizado" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "N&deg; de serie" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "sSC" + "</h3>" + "</td>";
+            cuerpoA += "<td>" + "<h3>" + "Marca" + "</h3>" + "</td>";
+            cuerpoA += "<td>" + "<h3>" + "Modelo" + "</h3>" + "</td>";
+
             cuerpoA += "<td>" + "<h3>" + "Direccion" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "Regi&oacute;n" + "</h3>" + "</td>";
             cuerpoA += "<td>" + "<h3>" + "Regi&oacute;n Seleccionada" + "</h3>" + "</td>";
@@ -498,10 +509,12 @@
                     acumulable += "<td>" + $(element).find("td").eq(8).html() + "</td>";
                     acumulable += "<td>" + $(element).find("td").eq(9).html() + "</td>";
                     acumulable += "<td>" + $(element).find("td").eq(10).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(11).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(12).html() + "</td>";
 
                     //region seleccionada
                     acumulable += "<td>" + $(".regionModificable_" + index).val() + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(12).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(14).html() + "</td>";
                     //ciudad Seleccionada
                     if (seleccionado == 0) {
                         acumulable += "<td>" + "No Seleccionado" + "</td>";
@@ -554,17 +567,17 @@
                         acumulable += "<td>" + "" + "</td>";
                     } 
                
-                    acumulable += "<td>" + $(element).find("td").eq(14).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(16).html() + "</td>";
                           // observacion tecnico
-                          acumulable += "<td>" + $(element).find("td").eq(21).html() + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(15).html() + "</td>";
+                          acumulable += "<td>" + $(element).find("td").eq(23).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(17).html() + "</td>";
                     // acumulable += "<td>" + $(element).find("td").eq(16).html() + "</td>";
                     acumulable += "<td>" + $(".valorAtencion_" + index).val().replaceAll(",", ".") + "</td>";
                     
                     acumulable += "<td>" + $(".valorTasladoModificale" + index).val().replaceAll(",", ".") + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(18).html().replaceAll(",", ".") + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(19).html() + "</td>";
-                    acumulable += "<td>" + $(element).find("td").eq(20).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(20).html().replaceAll(",", ".") + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(21).html() + "</td>";
+                    acumulable += "<td>" + $(element).find("td").eq(22).html() + "</td>";
                   
                     //console.log($(element).find("td").eq(17).html());
                     acumulable += "</tr>";
@@ -617,9 +630,9 @@
     $(document).ready(function() {
         $("#exportarExcel").click(function() {
             $('#tabla tr').each(function(index, element) {
-                traslado = $(element).find("td").eq(9).html();
-                subtotal = $(element).find("td").eq(10).html();
-                km = $(element).find("td").eq(12).html();
+                traslado = $(element).find("td").eq(11).html();
+                subtotal = $(element).find("td").eq(12).html();
+                km = $(element).find("td").eq(14).html();
                 variable = $("#variable").val();
                 variable1 = $("#variable1").val();
                 variable2 = $("#variable2").val();
