@@ -16,6 +16,40 @@ use GuzzleHttp\Client;
 Route::get('/', function () {
     return view('auth/login');
 });
+Route::get('admin/correos', 'menus\menu_principal@admin_correos')->name('go.administrador_correo');
+
+
+/*
+ADMINISTRADOR DE CORREOS
+*/
+Route::get('admin/correos', 'menus\menu_principal@admin_correos')->name('go.administrador_correo');
+Route::post('get/proyectos', 'menus\menu_principal@getproyectos')->name('go.getproyectos');
+Route::post('get/datacorreos', 'menus\menu_principal@datacorreos')->name('go.datacorreos');
+Route::post('change/estadocorreo', 'menus\menu_principal@cambioestadocorreo')->name('go.cambioestadocorreo');
+Route::post('guardar/guardarcorreos', 'menus\menu_principal@guardarcorreo')->name('go.guardarcorreo');
+
+
+/* */
+//formulario
+
+Route::get('formulario/solicitudes', 'menus\menu_principal@formsolicitudes')->name('go.formsolicitudes');
+
+Route::post('validarot', 'formulario\formularioController@validarOt')->name('go.validarot');
+Route::post('registrarformulario', 'formulario\formularioController@create')->name('registrar.formulario');
+Route::post('generarot', 'formulario\formularioController@generarOt')->name('go.generarOt');
+
+//INFORME BI
+
+Route::get('verinformesbiuno', 'informesbi\informesbiController@verinformesbiuno')->name('verinformesbiuno');
+Route::get('formularioinformesbi', 'informesbi\informesbiController@formularioinformesbi')->name('go.formularioinformesbi');
+Route::get('descargarinformeuno', 'informesbi\informesbiController@descargarinformeuno')->name('go.descargarinformeuno');
+
+
+// __________________
+
+Route::post('createproveedor', 'crearBdController@index')->name('crear.databaseproveedor');
+
+Route::get('nuevoproveedor', 'menus\menu_principal@nuevoproveedor')->name('go.nuevoproveedor');
 
  //SLA
  Route::get('sla', 'menus\menu_principal@sla')->name('go.sla');
@@ -271,9 +305,13 @@ Route::post('/cambiousuarioadicional', 'gastosreembolsos\CrearProyectoController
 
 //MANTENEDOR KILOMETROS
 Route::get('mantenedor_kilometros', 'prefactura\mantenedorController@index')->name('go.ver_mantenedor');
+
 //RUTA FILTRO MANTENEDOR KILOMETROS
 Route::get('filtros_mantenedor_kilometros', 'prefactura\mantenedorController@filtros_mantenedor_kilometros')->name('filtros_mantenedor_kilometros');
 Route::post('ver_datos_kilometros', 'prefactura\mantenedorController@ver_datos_kilometros')->name('go.ver_datos_kilometros');
+Route::post('ver_datos_kilometros_filtros', 'prefactura\mantenedorController@ver_datos_kilometros_filtros')->name('go.ver_datos_kilometros_filtros');
+
+
 Route::post('editar_kilometros', 'prefactura\mantenedorController@editar')->name('go.editar_kilometros');
 Route::get('crear_kilometros', 'prefactura\mantenedorController@create')->name('crearKilometros');
 Route::get('deleted_kilometro', 'prefactura\mantenedorController@destroy')->name('deleteRegistro');
@@ -424,6 +462,13 @@ Route::group(['middleware' => ['mydb']], function () {
     Route::post('/cambiodefechas', 'checklist\checklistController@cambiodefechafin')->name('cambiodefecha');
     Route::post('/cambiodefechas2', 'checklist\checklistController@cambiodefechainicio')->name('cambiodefecha2');
     Route::post('/cambiodefechassolicitudes', 'solicitudes\checkController@cambiodefechafinsolicitudes')->name('cambiodefechasolicitudes');
+    Route::post('/cambiodemarcar', 'solicitudes\checkController@cambiodemarca')->name('cambiodemarca');
+    Route::post('/cambiodeserie', 'solicitudes\checkController@cambiodeserie')->name('cambiodeserie');
+
+    Route::post('/cambiodemarcainstalacion', 'checklist\checklistController@cambiodemarcainstalacion')->name('cambiodemarcainstalacion');
+    Route::post('/cambiodeidinstalacion', 'checklist\checklistController@cambiodeidinstalacion')->name('cambiodeidinstalacion');
+
+
     Route::post('/cambiodecorreosolicitudes', 'solicitudes\checkController@cambiodecorreosolicitudes')->name('cambiodecorreosolicitud');
     Route::post('/cambiodecontadorbn', 'checklist\checklistController@cambiardecontadorbn')->name('cambiodecontadorbn');
     Route::post('/cambiodecontadorcc', 'checklist\checklistController@cambiardecontadorcc')->name('cambiodecontadorcc');
@@ -612,6 +657,8 @@ Route::group(['middleware' => ['mydb']], function () {
     //CORREO
     Route::get('correos', 'menus\menu_principal@correos')->name('go.correos');
     Route::post('cambio_envio', 'menus\menu_principal@cambio_envio')->name('go.cambio_envio');
+    Route::post('/cambiodeobservacionservicio', 'solicitudes\checkController@cambiodeobservacionservicio')->name('cambiodeobservacionservicio');
+
 });
 Route::get('completandocheck', 'checklist\checklistController@completar_checklist')->name('go.completando_check')->middleware(SetBd2::class);
 Route::get('vercheck/{idasig?}', 'checklist\checklistController@ver_checklist')->name('go.ver_check')->middleware(SetBd2::class);
@@ -639,6 +686,17 @@ Route::get('revisar_porasignar', 'HomeController@revisar_porasignar')->name('rev
 Route::get('revisar_encurso_coordinador', 'HomeController@revisar_encurso_coordinador')->name('revisar_encurso_coordinador');
 Route::get('revisar_porreasignar_coordinador', 'HomeController@revisar_porreasignar_coordinador')->name('revisar_porreasignar_coordinador');
 Route::get('revisar_porrevisar_coordinador', 'HomeController@revisar_porrevisar_coordinador')->name('revisar_porrevisar_coordinador');
+
+// OPCIONES KYOCERA
+Route::get('revisar_pendientes_coordinador_kyocera', 'HomeController@revisar_pendientes_coordinador_kyocera')->name('revisar_pendientes_coordinador_kyocera');
+Route::get('filtro_pendiente_kyocera', 'HomeController@filtro_pendiente_kyocera')->name('go.filtro_pendiente_kyocera');
+Route::get('revisar_porasignar_kyocera', 'HomeController@revisar_porasignar_kyocera')->name('revisar_porasignar_kyocera');
+Route::get('filtro_porasignar_kyocera', 'HomeController@filtro_porasignar_kyocera')->name('go.filtro_porasignar_kyocera');
+Route::get('revisar_porrevisar_coordinador_kyocera', 'HomeController@revisar_porrevisar_coordinador_kyocera')->name('revisar_porrevisar_coordinador_kyocera');
+Route::get('filtro_porrevisar_kyocera', 'HomeController@filtro_porrevisar_kyocera')->name('go.filtro_porrevisar_kyocera');
+
+
+
 //FILTRO HOME CORDINADOR
 Route::get('filtro_pendiente', 'HomeController@filtro_pendiente')->name('go.filtro_pendiente');
 Route::get('filtro_porasignar', 'HomeController@filtro_porasignar')->name('go.filtro_porasignar');
@@ -657,6 +715,8 @@ Route::get('revisar_porasignar_servicio', 'HomeController@revisar_porasignar_ser
 Route::get('revisar_encurso_coordinador_servicio', 'HomeController@revisar_encurso_coordinador_servicio')->name('revisar_encurso_coordinador_servicio');
 Route::get('revisar_porreasignar_coordinador_servicio', 'HomeController@revisar_porreasignar_coordinador_servicio')->name('revisar_porreasignar_coordinador_servicio');
 Route::get('revisar_porrevisar_coordinador_servicio', 'HomeController@revisar_porrevisar_coordinador_servicio')->name('revisar_porrevisar_coordinador_servicio');
+Route::get('revisar_porrevisar_coordinador_servicio_filtro', 'HomeController@revisar_porrevisar_coordinador_servicio_filtro')->name('revisar_porrevisar_coordinador_servicio_filtro');
+
 Route::get('instalar_repuestos', 'HomeController@estado_intalar_repuestos')->name('instalar_repuestos');
 Route::get('solicitud_repuestos', 'HomeController@solicitud_repuestos')->name('solicitud_repuestos');
 
